app/soc/views/document/show.py
changeset 512 aae25d2b4464
parent 500 44ea4620c5c0
child 513 3c1e16637ad7
--- a/app/soc/views/document/show.py	Thu Nov 20 18:06:43 2008 +0000
+++ b/app/soc/views/document/show.py	Thu Nov 20 18:50:30 2008 +0000
@@ -38,7 +38,7 @@
 DEF_DOCS_PUBLIC_TMPL = 'soc/document/public.html'
 
 @decorators.view
-def public(request, page_name=None, partial_path=None, link_name=None,
+def public(request, page_name=None, partial_path=None, link_id=None,
            template=DEF_DOCS_PUBLIC_TMPL):
   """How the "general public" sees a Document.
 
@@ -46,8 +46,8 @@
     request: the standard django request object
     page_name: the page name displayed in templates as page and header title
     partial_path: the Document's site-unique "path" extracted from the URL,
-      minus the trailing link_name
-    link_name: the last portion of the Document's site-unique "path"
+      minus the trailing link_id
+    link_id: the last portion of the Document's site-unique "path"
       extracted from the URL
     template: the "sibling" template (or a search list of such templates)
       from which to construct the public.html template name (or names)
@@ -68,14 +68,14 @@
   
   doc = None
 
-  # try to fetch User entity corresponding to link_name if one exists
-  path = path_link_name.combinePath([partial_path, link_name])
+  # try to fetch User entity corresponding to link_id if one exists
+  path = path_link_name.combinePath([partial_path, link_id])
 
   # try to fetch Document entity corresponding to path if one exists    
   try:
     if path:
       doc = document.logic.getFromFields(partial_path=partial_path,
-                                         link_name=link_name)
+                                         link_id=link_id)
   except out_of_band.ErrorResponse, error:
     # show custom 404 page when Document path doesn't exist in Datastore
     return simple.errorResponse(request, page_name, error, template, context)